=====
dashi
=====

|docs|

Elaborate data analyses are possible with the functionality offered by the great
`numpy <http://numpy.scipy.org/>`_, `matplotlib
<http://matplotlib.sourceforge.net/>`_, and `pytables
<http://www.pytables.org/moin>`_ libraries. However their support for
HEP-typical problems (histograms, fitting routines,visualization of those,..) is
limited. Dashi is intended to be a thin wrapper around these libraries to
provide some useful tools for these problems without obstructing the user the access
to the underlying libraries and without being a dependency sink.

Installation
============

The easiest way to install dashi is with `pip`::

	pip install https://github.com/emiddell/dashi/zipball/master

Documentation
=============

- `Documentation <https://dashi.readthedocs.org/>`_
- `Examples <https://github.com/emiddell/dashi/tree/master/dashi/examples/>`_
